
%%%------------------------------------------------------------------------
%% Copyright The OpenTelemetry Authors
%% Licensed under the Apache License, Version 2.0 (the "License");
%% you may not use this file except in compliance with the License.
%% You may obtain a copy of the License at
%%
%% http://www.apache.org/licenses/LICENSE-2.0
%%
%% Unless required by applicable law or agreed to in writing, software
%% distributed under the License is distributed on an "AS IS" BASIS,
%% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
%% See the License for the specific language governing permissions and
%% limitations under the License.
%%%-------------------------------------------------------------------------
-include_lib("opentelemetry_semantic_conventions/include/attributes/vcs_attributes.hrl").


%% The ID of the change (pull request/merge request/changelist) if applicable. This is usually a unique (within repository) identifier generated by the VCS system.
%%  
-define(VCS_CHANGE_ID, 'vcs.change.id').


%% The state of the change (pull request/merge request/changelist).
%%  
-define(VCS_CHANGE_STATE, 'vcs.change.state').

-define(VCS_CHANGE_STATE_VALUES_OPEN, 'open').

-define(VCS_CHANGE_STATE_VALUES_WIP, 'wip').

-define(VCS_CHANGE_STATE_VALUES_CLOSED, 'closed').

-define(VCS_CHANGE_STATE_VALUES_MERGED, 'merged').



%% The human readable title of the change (pull request/merge request/changelist). This title is often a brief summary of the change and may get merged in to a ref as the commit summary.
%%  
-define(VCS_CHANGE_TITLE, 'vcs.change.title').


%% The type of line change being measured on a branch or change.
%%  
-define(VCS_LINE_CHANGE_TYPE, 'vcs.line_change.type').

-define(VCS_LINE_CHANGE_TYPE_VALUES_ADDED, 'added').

-define(VCS_LINE_CHANGE_TYPE_VALUES_REMOVED, 'removed').



%% The group owner within the version control system.
%%  
-define(VCS_OWNER_NAME, 'vcs.owner.name').


%% The name of the version control system provider.
%%  
-define(VCS_PROVIDER_NAME, 'vcs.provider.name').

-define(VCS_PROVIDER_NAME_VALUES_GITHUB, 'github').

-define(VCS_PROVIDER_NAME_VALUES_GITLAB, 'gitlab').

-define(VCS_PROVIDER_NAME_VALUES_GITTEA, 'gittea').

-define(VCS_PROVIDER_NAME_VALUES_GITEA, 'gitea').

-define(VCS_PROVIDER_NAME_VALUES_BITBUCKET, 'bitbucket').



%% The name of the [reference](https://git-scm.com/docs/gitglossary#def_ref) such as **branch** or **tag** in the repository.
%%  
-define(VCS_REF_BASE_NAME, 'vcs.ref.base.name').


%% The revision, literally [revised version](https://www.merriam-webster.com/dictionary/revision), The revision most often refers to a commit object in Git, or a revision number in SVN.
%%  
-define(VCS_REF_BASE_REVISION, 'vcs.ref.base.revision').


%% The type of the [reference](https://git-scm.com/docs/gitglossary#def_ref) in the repository.
%%  
-define(VCS_REF_BASE_TYPE, 'vcs.ref.base.type').

-define(VCS_REF_BASE_TYPE_VALUES_BRANCH, 'branch').

-define(VCS_REF_BASE_TYPE_VALUES_TAG, 'tag').



%% The name of the [reference](https://git-scm.com/docs/gitglossary#def_ref) such as **branch** or **tag** in the repository.
%%  
-define(VCS_REF_HEAD_NAME, 'vcs.ref.head.name').


%% The revision, literally [revised version](https://www.merriam-webster.com/dictionary/revision), The revision most often refers to a commit object in Git, or a revision number in SVN.
%%  
-define(VCS_REF_HEAD_REVISION, 'vcs.ref.head.revision').


%% The type of the [reference](https://git-scm.com/docs/gitglossary#def_ref) in the repository.
%%  
-define(VCS_REF_HEAD_TYPE, 'vcs.ref.head.type').

-define(VCS_REF_HEAD_TYPE_VALUES_BRANCH, 'branch').

-define(VCS_REF_HEAD_TYPE_VALUES_TAG, 'tag').



%% The type of the [reference](https://git-scm.com/docs/gitglossary#def_ref) in the repository.
%%  
-define(VCS_REF_TYPE, 'vcs.ref.type').

-define(VCS_REF_TYPE_VALUES_BRANCH, 'branch').

-define(VCS_REF_TYPE_VALUES_TAG, 'tag').


%% @deprecated Deprecated, use `vcs.change.id` instead.
%% Deprecated, use `vcs.change.id` instead.
%%  
-define(VCS_REPOSITORY_CHANGE_ID, 'vcs.repository.change.id').

%% @deprecated Deprecated, use `vcs.change.title` instead.
%% Deprecated, use `vcs.change.title` instead.
%%  
-define(VCS_REPOSITORY_CHANGE_TITLE, 'vcs.repository.change.title').


%% The human readable name of the repository. It SHOULD NOT include any additional identifier like Group/SubGroup in GitLab or organization in GitHub.
%%  
-define(VCS_REPOSITORY_NAME, 'vcs.repository.name').

%% @deprecated Deprecated, use `vcs.ref.head.name` instead.
%% Deprecated, use `vcs.ref.head.name` instead.
%%  
-define(VCS_REPOSITORY_REF_NAME, 'vcs.repository.ref.name').

%% @deprecated Deprecated, use `vcs.ref.head.revision` instead.
%% Deprecated, use `vcs.ref.head.revision` instead.
%%  
-define(VCS_REPOSITORY_REF_REVISION, 'vcs.repository.ref.revision').

%% @deprecated Deprecated, use `vcs.ref.head.type` instead.
%% Deprecated, use `vcs.ref.head.type` instead.
%%  
-define(VCS_REPOSITORY_REF_TYPE, 'vcs.repository.ref.type').

-define(VCS_REPOSITORY_REF_TYPE_VALUES_BRANCH, 'branch').

-define(VCS_REPOSITORY_REF_TYPE_VALUES_TAG, 'tag').



%% The [canonical URL](https://support.google.com/webmasters/answer/10347851?hl=en#:~:text=A%20canonical%20URL%20is%20the,Google%20chooses%20one%20as%20canonical.) of the repository providing the complete HTTP(S) address in order to locate and identify the repository through a browser.
%%  
-define(VCS_REPOSITORY_URL_FULL, 'vcs.repository.url.full').


%% The type of revision comparison.
%%  
-define(VCS_REVISION_DELTA_DIRECTION, 'vcs.revision_delta.direction').

-define(VCS_REVISION_DELTA_DIRECTION_VALUES_BEHIND, 'behind').

-define(VCS_REVISION_DELTA_DIRECTION_VALUES_AHEAD, 'ahead').

